@@ -184,10 +184,10 @@ protectedServer <- function(server, client_id, client_secret=NULL, base_url="htt
                                                  path="v1/oauth2/token",
                                                  query=NULL,
                                                  body=oauth_params,
-                                                 env=solvebio::createEnv(),
+                                                 env=solvebio::createEnv(token=''),
                                                  content_type="application/x-www-form-urlencoded")
                                     }, error = function(e) {
-                                        stop("ERROR: Unable to retrieve SolveBio OAuth2 token. Check your client_id and client_secret (if used).")
+                                        stop(sprintf("ERROR: Unable to retrieve SolveBio OAuth2 token. Check your client_id and client_secret (if used). Error: %s\n", e))
                                     })
 
                                     # Set an auth cookie using a JS cookie library
